#
# spec file for package iredis
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           iredis
Version:        1.14.1
Release:        1.1
Summary:        Terminal client for Redis with auto-completion and syntax highlighting
License:        BSD-3-Clause
URL:            https://iredis.xbin.io/
Source:         https://github.com/laixintao/iredis/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-poetry
BuildRequires:  python3-setuptools
# SECTION tests
# for killall
BuildRequires:  psmisc
BuildRequires:  python3-Pygments >= 2
BuildRequires:  python3-click >= 8.0
BuildRequires:  python3-configobj >= 5.0
BuildRequires:  python3-mistune >= 3.0
BuildRequires:  python3-packaging >= 23.0
BuildRequires:  python3-pendulum >= 2.1.0
BuildRequires:  python3-pexpect
BuildRequires:  python3-pip
BuildRequires:  python3-prompt_toolkit >= 3
BuildRequires:  python3-pytest
BuildRequires:  python3-redis >= 4.5.3
BuildRequires:  python3-wcwidth >= 0.1.9
BuildRequires:  python3-wheel
BuildRequires:  redis >= 5.0.0
# /SECTION
Requires:       python3-Pygments >= 2
Requires:       python3-click >= 8.0
Requires:       python3-configobj >= 5.0
Requires:       python3-mistune >= 2.0
Requires:       python3-packaging >= 23.0
Requires:       python3-pendulum >= 2.1.0
Requires:       python3-prompt_toolkit >= 3
Requires:       python3-redis >= 3
Requires:       python3-wcwidth >= 0.1.9
Recommends:     redis >= 5.0.0
BuildArch:      noarch

%description
A terminal client for redis with auto-completion and syntax
highlighting. IRedis lets one type Redis commands, and it displays results.

IRedis is an alternative for redis-cli. In most cases, IRedis behaves
exactly the same as redis-cli. IRedis will prevent accidentally
running dangerous commands.

%prep
%setup -q -n iredis-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python3_sitelib}

%check
# increase the timeouts
sed -i 's/timeout=1/timeout=5/' tests/cli_tests/test_*.py
sed -i 's/timeout=2/timeout=5/' tests/cli_tests/test_*.py
sed -i 's/timeout=10/timeout=20/' tests/cli_tests/test_*.py
# the tests are extremely flaky on i586 (hitting timeouts), as long as x86_64 succeeds, we don't care as this is noarch
%ifnarch %ix86
%{_sbindir}/redis-server --port 6379 &
# wait for redis startup
sleep 2
# disable snapshots
redis-cli CONFIG SET save ""
# skip test_abort_reading_connection as it fails frequently (timeout) on OBS for no apparent reason, others are bugs upstream: https://github.com/laixintao/iredis/issues/417
# skip test_peek_zset_fetch_all, test_peek_zset_fetch_part, reported upstream: https://github.com/laixintao/iredis/issues/432
# skip test_auto_select_db_and_auth_for_reconnect_only_6 needs further inspection
# skip test_timer and test_command_completion_when_a_command_is_another_command_substring and test_trasaction_syntax_error and test_subscribe because of timeouts (too slow) on s390x
REDIS_VERSION=$(%{_sbindir}/redis-server --version | grep -o '[0-9]' | head -n 1) PATH=${PATH:+$PATH:}%{buildroot}%{_bindir} PYTHONPATH=${PYTHONPATH:+$PYTHONPATH:}%{buildroot}%{python3_sitelib} PYTHONDONTWRITEBYTECODE=1 pytest --ignore=_build.python3 -vv -k 'not (test_abort_reading_connection or test_peek_set_fetch_part or test_peek_stream or test_timestamp_completer_humanize_time_completion or test_peek_zset_fetch_all or test_peek_zset_fetch_part or test_auto_select_db_and_auth_for_reconnect_only_6 or test_timer or test_command_completion_when_a_command_is_another_command_substring) or test_trasaction_syntax_error or test_subscribe'
killall redis-server
%endif

%files
%{python3_sitelib}/iredis/
%{python3_sitelib}/iredis-%{version}*-info
%{_bindir}/iredis
%license LICENSE

%changelog
* Sun Mar 17 2024 Sebastian Wagner <sebix@sebix.at>
- Update to version 1.14.1:
  - Bugfix: fix argument parsing, `"foo\nbar"` will be parsed to `foo` and `\`
  and `n` and `bar`, the `\` and `n` should be one character `\n` instead.
- Ignore test_trasaction_syntax_error and test_subscribe because of timeouts (too slow) on s390x
* Mon Dec 18 2023 Sebastian Wagner <sebix@sebix.at>
- skip test_timer and test_command_completion_when_a_command_is_another_command_substring because of timeouts (too slow) on s390x
* Tue Oct 31 2023 Sebastian Wagner <sebix@sebix.at>
- switch to pyproject
- tests: disable redis snapshots, seem to be the default now
- update to version 1.14.0:
  - Dependency: upgrade redis-py to 5 (thanks to [chayim])
  - Feature: porting to redis-server 7.2 now
  - Feature: supports python 3.10, 3.11 now
  - Doc: update commands.json from redis-doc to latest version
* Fri Sep 15 2023 Sebastian Wagner <sebix@sebix.at>
- update to version 1.3.2:
  - upgrade mistune to v3
  - deprecate importlib_resources. use buildin now.
  - fix: fix data types changes in redis 7
  - fix restore command
* Thu Aug 10 2023 Sebastian Wagner <sebix@sebix.at>
- update to version 1.13.1:
  * fix slowlog get render: ms -> us (#463)
* Mon Jan  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.13:
  * Drop Python 3.6 support
- includes changes from 1.12.2:
  * honor ssl_cert_reqs strategy via --verify-ssl or a rediss://
    URL parameter ssl_cert_reqs
* Wed Aug 31 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.12.1:
  - support HRANDFIELD. by @laixintao in #431
  - add testing on redis 7. by @laixintao in #433
  - bugfix: fix error when pop multiple elements by @Mr3h1v in #436
  - Allow to provide a custom prompt via --prompt by @aymericbeaumet in #437
  - support username for client connection by @laixintao in #438
  - support client_addr and client_id in prompt string, add some tests. by @laixintao in #440
  - support prompt in iredisrc config file by @laixintao in #441
* Wed Jun 29 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- disable some failing tests (reported upstream) to fix the build.
* Wed Jun 29 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.12:
  - Feature: CLIENT KILL now support LADDR argument.
  - Feature: CLIENT LIST now support ID argument.
  - Feature: CLIENT PAUSE support options and added CLIENT UNPAUSE command.
  - Feature: CLIENT TRACKING support multiple prefixes.
  - Feature: support new command: CLIENT TRACKINGINFO.
  - Feature: support new command: COPY.
  - Feature: support new command: EVAL_RO and EVALSHA_RO.
  - Feature: support new command: EXPIRETIME.
  - Feature: support new command: FAILOVER.
  - Feature: support new command: GEOSEARCH.
  - Feature: support new command: GEOSEARCHRESTORE.
  - Feature: support new command: GETDEL.
  - Feature: support new command: GETEX.
  - Feature: FLUSHDB and FLUSHALL supports SYNC option.
  - Feature: GEOADD supports CH XX NX options.
  - Feature: Timestamp Completers are now support completion for timestamp fields and milliseconds timestamp fields.
  - Deprecate: GEORADIUS is deprecated, no auto-complete for this command anymore.
  - Deprecate: GEORADIUSBYMEMBER is deprecated, no auto-complete for this command anymore.
- update to version 1.11.1:
  - Bugfix: Switch distutils.version to packaging.version to fix the version parse for windows. (new dependency: pypi's python-packaging.
* Fri Jan 28 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Skip a few failings tests (bugs upstream).
* Tue Jan 25 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.11.0:
  - Introduce codespell to find typos by @tssujt in #411
  - upgrade mistune to ^2.0 by @laixintao in #416
* Mon Jan 10 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.10.0:
  - Feature: more human readable output for HELP command like ACL HELP and MEMORY HELP.
  - Feature: you can use Ctrl + C to cancel a blocking command like BLPOP.
  - Test: IRedis now tested under ubuntu-latest (before is ubuntu-16.04)
  - Dependency: Support Python 3.10 now, thanks to tssujt.
* Mon Nov 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Sun Nov 21 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 1.9.4.
